@@ -52,8 +52,6 @@
 #include <qdatastream.h>
 #include <qbuffer.h>
 
-#include <klocale.h>
-
 KigFilterKSeg::KigFilterKSeg()
 {
 }
@@ -137,7 +135,7 @@ static ObjectTypeCalcer* intersectionPoint( const std::vector<ObjectCalcer*>& pa
   else return 0;
 }
 
-ObjectCalcer* KigFilterKSeg::transformObject( const QString& file, KigDocument& kigdoc,
+ObjectCalcer* KigFilterKSeg::transformObject( KigDocument& kigdoc,
                                               std::vector<ObjectCalcer*>& parents,
                                               int subtype, bool& ok )
 {
@@ -179,9 +177,9 @@ ObjectCalcer* KigFilterKSeg::transformObject( const QString& file, KigDocument&
       else
       {
         // TODO
-        notSupported( file, i18n( "This KSeg document uses a scaling "
-                                  "transformation, which Kig currently "
-                                  "cannot import." ) );
+        notSupported( i18n( "This KSeg document uses a scaling "
+                            "transformation, which Kig currently "
+                            "cannot import." ) );
         ok = false;
         return 0;
       }
@@ -304,7 +302,7 @@ KigDocument* KigFilterKSeg::load( const QString& file )
     int width = style.pen.width();
 
 /*
-    kDebug() << "type: " << type
+    qDebug() << "type: " << type
               << "descendtype: " << descendtype << endl
               << "label: " << labeltext << endl;
 //*/
@@ -320,7 +318,7 @@ KigDocument* KigFilterKSeg::load( const QString& file )
         case G_SCALED:
         case G_REFLECTED:
         {
-          o = transformObject( file, *retdoc, parents, descendtype, ok );
+          o = transformObject(  *retdoc, parents, descendtype, ok );
           break;
         }
         case G_FREE_POINT:
@@ -385,7 +383,7 @@ KigDocument* KigFilterKSeg::load( const QString& file )
         case G_SCALED:
         case G_REFLECTED:
         {
-          o = transformObject( file, *retdoc, parents, descendtype, ok );
+          o = transformObject(  *retdoc, parents, descendtype, ok );
           break;
         }
         case G_ENDPOINTS_SEGMENT:
@@ -408,7 +406,7 @@ KigDocument* KigFilterKSeg::load( const QString& file )
         case G_SCALED:
         case G_REFLECTED:
         {
-          o = transformObject( file, *retdoc, parents, descendtype, ok );
+          o = transformObject(  *retdoc, parents, descendtype, ok );
           break;
         }
         case G_TWOPOINTS_RAY:
@@ -438,7 +436,7 @@ KigDocument* KigFilterKSeg::load( const QString& file )
         case G_SCALED:
         case G_REFLECTED:
         {
-          o = transformObject( file, *retdoc, parents, descendtype, ok );
+          o = transformObject(  *retdoc, parents, descendtype, ok );
           break;
         }
         case G_TWOPOINTS_LINE:
@@ -473,7 +471,7 @@ KigDocument* KigFilterKSeg::load( const QString& file )
         case G_SCALED:
         case G_REFLECTED:
         {
-          o = transformObject( file, *retdoc, parents, descendtype, ok );
+          o = transformObject(  *retdoc, parents, descendtype, ok );
           break;
         }
         case G_CENTERPOINT_CIRCLE:
@@ -520,7 +518,7 @@ KigDocument* KigFilterKSeg::load( const QString& file )
         case G_SCALED:
         case G_REFLECTED:
         {
-          o = transformObject( file, *retdoc, parents, descendtype, ok );
+          o = transformObject(  *retdoc, parents, descendtype, ok );
           break;
         }
         case G_THREEPOINTS_ARC:
@@ -543,7 +541,7 @@ KigDocument* KigFilterKSeg::load( const QString& file )
         case G_SCALED:
         case G_REFLECTED:
         {
-          o = transformObject( file, *retdoc, parents, descendtype, ok );
+          o = transformObject(  *retdoc, parents, descendtype, ok );
           break;
         }
         default:
@@ -558,20 +556,20 @@ KigDocument* KigFilterKSeg::load( const QString& file )
       };
       case G_CIRCLEINTERIOR:
       {
-        notSupported( file, i18n( "This KSeg file contains a filled circle, "
-                                  "which Kig does not currently support." ) );
+        notSupported( i18n( "This KSeg file contains a filled circle, "
+                            "which Kig does not currently support." ) );
         return 0;
       };
       case G_ARCSECTOR:
       {
-        notSupported( file, i18n( "This KSeg file contains an arc sector, "
-                                  "which Kig does not currently support." ) );
+        notSupported( i18n( "This KSeg file contains an arc sector, "
+                            "which Kig does not currently support." ) );
         return 0;
       };
       case G_ARCSEGMENT:
       {
-        notSupported( file, i18n( "This KSeg file contains an arc segment, "
-                                  "which Kig does not currently support." ) );
+        notSupported( i18n( "This KSeg file contains an arc segment, "
+                            "which Kig does not currently support." ) );
         return 0;
       };
       case G_LOCUS:
@@ -583,7 +581,7 @@ KigDocument* KigFilterKSeg::load( const QString& file )
         case G_SCALED:
         case G_REFLECTED:
         {
-          o = transformObject( file, *retdoc, parents, descendtype, ok );
+          o = transformObject(  *retdoc, parents, descendtype, ok );
           break;
         }
         case G_OBJECT_LOCUS:
